==> jbpm-distro-4.1.jar: jbpm-4.1/src/org/jbpm/jpdl/internal/activity/EndBinding.java <==
/*
 * JBoss, Home of Professional Open Source
 * Copyright 2005, JBoss Inc., and individual contributors as indicated
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.jbpm.jpdl.internal.activity;

import org.jbpm.pvm.internal.util.XmlUtil;
import org.jbpm.pvm.internal.xml.Parse;
import org.jbpm.pvm.internal.xml.Parser;
import org.w3c.dom.Element;


/**
 * @author Tom Baeyens
 */
public class EndBinding extends JpdlBinding {

  public EndBinding() {
    super("end");
  }

  protected EndBinding(String tag) {
    super(tag);
  }

  public Object parse(Element element, Parse parse, Parser parser) {
    
    boolean endProcessInstance = true;
    String ends = XmlUtil.attribute(element, "ends", false, parse);
    if ("execution".equalsIgnoreCase(ends)) {
      endProcessInstance = false;
    }
    
    String state = XmlUtil.attribute(element, "state", false, parse);
    
    EndActivity endActivity = new EndActivity();
    endActivity.setEndProcessInstance(endProcessInstance);
    endActivity.setState(state);
    
    return endActivity;
  }
}

==> jbpm-distro-4.3.jar: jbpm-4.3/src/org/jbpm/jpdl/internal/activity/EndBinding.java <==
/*
 * JBoss, Home of Professional Open Source
 * Copyright 2005, JBoss Inc., and individual contributors as indicated
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.jbpm.jpdl.internal.activity;

import org.jbpm.jpdl.internal.xml.JpdlParser;
import org.jbpm.pvm.internal.util.XmlUtil;
import org.jbpm.pvm.internal.xml.Parse;
import org.w3c.dom.Element;


/**
 * @author Tom Baeyens
 */
public class EndBinding extends JpdlBinding {

  public EndBinding() {
    super("end");
  }

  protected EndBinding(String tag) {
    super(tag);
  }

  public Object parseJpdl(Element element, Parse parse, JpdlParser parser) {
    
    boolean endProcessInstance = true;
    String ends = XmlUtil.attribute(element, "ends", false, parse);
    if ("execution".equalsIgnoreCase(ends)) {
      endProcessInstance = false;
    }
    
    String state = XmlUtil.attribute(element, "state", false, parse);
    
    EndActivity endActivity = new EndActivity();
    endActivity.setEndProcessInstance(endProcessInstance);
    endActivity.setState(state);
    
    return endActivity;
  }
}
